==> haskell-configurator-ng-0.0.0.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-configurator-ng.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator-ng
version: 0.0.0.1
id: configurator-ng-0.0.0.1-FQhZIfzgLf7JQVdg7xOhhN
key: configurator-ng-0.0.0.1-FQhZIfzgLf7JQVdg7xOhhN
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
           Copyright 2015-2016 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
stability: experimental
homepage: http://github.com/lpsmith/configurator-ng
synopsis: The next generation of configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    * An expressive applicative/monadic high-level parsing interface
    to gracefully scale to more complicated configuration needs,  with
    powerful diagnostic messaging mechanism.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
author: Bryan O'\''Sullivan, Leon P Smith
exposed: True
indefinite: False
exposed-modules:
    Data.Configurator Data.Configurator.Config
    Data.Configurator.Config.Internal Data.Configurator.FromValue
    Data.Configurator.FromValue.Internal Data.Configurator.Parser
    Data.Configurator.Parser.Internal Data.Configurator.Types
hidden-modules: Data.Configurator.Config.Implementation
                Data.Configurator.Parser.Implementation
                Data.Configurator.FromValue.Implementation Data.Configurator.Syntax
                Data.Configurator.Types.Internal
abi: 8c009cf15d8141cc3c6a87cedf3eb03e
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/configurator-ng-0.0.0.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/configurator-ng-0.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/configurator-ng-0.0.0.1
hs-libraries: HSconfigurator-ng-0.0.0.1-FQhZIfzgLf7JQVdg7xOhhN
depends:
    attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j base-4.10.0.0
    bytestring-0.10.8.2 critbit-0.2.0.0-G5zQ7RoTicJ7geCzptapcu
    dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q directory-1.3.0.2
    data-ordlist-0.4.7.0-FbL4nCzWBaaILSIRV0UBHS
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    scientific-0.3.5.1-imIXdjJRiA7LRtcu2MlFY
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
abi-depends: attoparsec-0.13.2.0-KKDeQTJJuS9ICqGr2jqA4j=408c5a9ef40ae69c083ed9d4aba83592
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             critbit-0.2.0.0-G5zQ7RoTicJ7geCzptapcu=4be3a381e5562c5ae39fe925a129b864
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=39b750082c56951484aa28fb24175e9c
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             data-ordlist-0.4.7.0-FbL4nCzWBaaILSIRV0UBHS=9ba6857fb7b65a96829753ee152218bb
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             scientific-0.3.5.1-imIXdjJRiA7LRtcu2MlFY=147f92d1044da8ff4805281d8437c52f
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=de9563896484115ad3fe305bce9cecd3
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
haddock-interfaces: /usr/share/doc/haskell-configurator-ng/html/configurator-ng.haddock
haddock-html: /usr/share/doc/haskell-configurator-ng/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-ng-0.0.0.1-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-configurator-ng.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator-ng
version: 0.0.0.1
id: configurator-ng-0.0.0.1-ANFRGAw0gkZ9q2I19PPe0I
key: configurator-ng-0.0.0.1-ANFRGAw0gkZ9q2I19PPe0I
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
           Copyright 2015-2016 Leon P Smith
maintainer: Leon P Smith <leon@melding-monads.com>
stability: experimental
homepage: http://github.com/lpsmith/configurator-ng
synopsis: The next generation of configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    * An expressive applicative/monadic high-level parsing interface
    to gracefully scale to more complicated configuration needs,  with
    powerful diagnostic messaging mechanism.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
author: Bryan O'\''Sullivan, Leon P Smith
exposed: True
indefinite: False
exposed-modules:
    Data.Configurator Data.Configurator.Config
    Data.Configurator.Config.Internal Data.Configurator.FromValue
    Data.Configurator.FromValue.Internal Data.Configurator.Parser
    Data.Configurator.Parser.Internal Data.Configurator.Types
hidden-modules: Data.Configurator.Config.Implementation
                Data.Configurator.Parser.Implementation
                Data.Configurator.FromValue.Implementation Data.Configurator.Syntax
                Data.Configurator.Types.Internal
abi: 885e0168a1399bb9f9063b86125030ba
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/configurator-ng-0.0.0.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/configurator-ng-0.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/configurator-ng-0.0.0.1
hs-libraries: HSconfigurator-ng-0.0.0.1-ANFRGAw0gkZ9q2I19PPe0I
depends:
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm base-4.10.0.0
    bytestring-0.10.8.2 critbit-0.2.0.0-G5zQ7RoTicJ7geCzptapcu
    dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q directory-1.3.0.2
    data-ordlist-0.4.7.0-FbL4nCzWBaaILSIRV0UBHS
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
abi-depends: attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=abc33533d9d12ab781226d56fe2dc420
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             critbit-0.2.0.0-G5zQ7RoTicJ7geCzptapcu=4be3a381e5562c5ae39fe925a129b864
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=39b750082c56951484aa28fb24175e9c
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             data-ordlist-0.4.7.0-FbL4nCzWBaaILSIRV0UBHS=9ba6857fb7b65a96829753ee152218bb
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=de9563896484115ad3fe305bce9cecd3
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
haddock-interfaces: /usr/share/doc/haskell-configurator-ng/html/configurator-ng.haddock
haddock-html: /usr/share/doc/haskell-configurator-ng/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
